/**
  *  \file client/actions/gatax.cc
  *
  *  (c) 2001-2016 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/actions/gatax.h"
#include "ui/msgbox.h"
#include "util/nls.h"
#include "cpluslib/format.h"
#include "game/planet.h"
#include "int/mutex.h"
#include "game/planetform.h"

class WGlobalAutotaxAction::Executer : public WGlobalActionExecuter {
    int what;
 public:
    Executer(int what);
    bool execute(GObject& obj, bool lock);
    void finish(int obj, int success);
};

WGlobalAutotaxAction::WGlobalAutotaxAction(int what)
    : what(what)
{ }

WGlobalActionExecuter*
WGlobalAutotaxAction::prepare()
{
    if (UIMessageBox(_("Do you want to set all tax rates?"), _("Global Actions")).doYesNoDialog()) {
        return new Executer(what);
    } else {
        return 0;
    }
}

WGlobalAutotaxAction::Executer::Executer(int what)
    : what(what)
{ }

bool
WGlobalAutotaxAction::Executer::execute(GObject& obj, bool lock)
{
    bool did = false;
    GPlanet* pl = dynamic_cast<GPlanet*>(&obj);
    if (pl != 0 && pl->isPlayable(GObject::Playable)) {
        /* Check lock */
        if (lock || IntMutex::query(format("P%d.TAX", pl->getId())) == 0) {
            /* Colonists */
            if ((what & Colonists) != 0) {
                mp16_t val = getColonistSafeTax(*pl, pl->getStructures(str_Mines) + pl->getStructures(str_Factories));
                if (val.isKnown() && val != pl->getColonistTax()) {
                    pl->setColonistTax(val);
                    did = true;
                }
            }
            /* Natives */
            if ((what & Natives) != 0 && pl->getNatives() > 0) {
                mp16_t val = getNativeSafeTax(*pl, pl->getStructures(str_Mines) + pl->getStructures(str_Factories));
                if (val.isKnown() && val != pl->getNativeTax()) {
                    pl->setNativeTax(val);
                    did = true;
                }
            }
        }
    }
    return did;
}

void
WGlobalAutotaxAction::Executer::finish(int /*obj*/, int success)
{
    messageBox(format(_("Taxes have been changed on %d planet%!1{s%}."), success), _("Global Actions"));
}
