/**
  *  \file client/chart/tilecontainer.h
  *  \brief Starchart Tile Container
  *
  *  (c) 2001-2016 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_CHART_TILECONTAINER_H
#define PCC_V2_CLIENT_CHART_TILECONTAINER_H

#include "ui/ui.h"
#include "client/tiles.h"
#include "ui/skin.h"

class GfxContext;
class GChartViewport;

class WStarchartTileSkin : public UISkin {
 public:
    WStarchartTileSkin()
        : UISkin(DARK_COLOR_SET)
        { }
    void drawBackground(GfxContext& ctx, GfxRect r);

    static void drawFancyBar(GfxCanvas& can, GfxRect r);
};

class WStarchartTileContainer : public UIBaseWidget, public WTileContainer {
    ObjectHolder h;
    WStarchartTileSkin skin;
 public:
    WStarchartTileContainer();

    virtual void       drawContent(GfxCanvas& canvas);                       // draw content of widget, end-users override this
    virtual void       drawEverything(GfxCanvas& canvas);                    // draw everything including children, bases override this
    virtual void       drawBelow(UIBaseWidget& child, GfxCanvas& canvas);    // draw everything below child, bases override this
    virtual GfxCanvas& getCanvasFor(UIBaseWidget& child, ObjectHolder& mgr); // get canvas to draw child on, bases override this
    virtual bool       handleEvent(const UIEvent& event, bool second_pass);   // can be overridden by whoever needs it, base provides default
    virtual void       onAddRemoveChild(UIBaseWidget& the_widget, bool added); // overridden in base
    virtual void       getLayoutInfo(LayoutInfo&);                          // overridden by everyone
    virtual void       onResize(GfxRect oldsize, bool by_layout);           // overridden in base
    virtual void       onChildResize(UIBaseWidget& child, GfxRect oldsize); // overridden in base
    virtual int        run();                 // overridden in root
    virtual void       stop(int arg);         // overridden in root

    void doLayout(GChartViewport& viewport);
    void addNewTile(WTile* w);
};

#endif
