/**
  *  \file ui/prefix.h
  *  \brief Prefix Argument Handling
  *
  *  (c) 2001-2016 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_PREFIX_H
#define PCC_V2_UI_PREFIX_H

#include "ui/ui.h"

/** Prefix argument input. This class processes keys intended for a
    prefix argument. */
class UIPrefixArgInput {
    /** Operator. */
    enum Operator {
        NoOp,                   ///< No operator specified so far
        MultiplyOp,             ///< '*' operator.
        DivideOp                ///< '/' operator.
    };

    int value;                  ///< First value. Only value if NoOp.
    int second_value;           ///< Second value for operators. Can be 0 if none entered yet (in this case, the operator is ignored as well).
    Operator op;                ///< Active operator.

 public:
    enum Action {
        NotHandled,
        Accepted,
        Canceled
    };

    explicit UIPrefixArgInput(int value);
    string_t getText() const;
    int getValue() const;
    Action handleKey(uint32_t key);
};

/** Prefix argument trigger. This widget, when added to a group, will
    allow the user to specify a prefix argument. It is invisible, but
    will call startPrefixArg() to display the input popup when the
    user types a digit key. In the first event handling pass, it only
    accepts Alt+digit, in the second pass, it also accepts regular
    digits; this allows coexistence with regular input widgets. */
class UIPrefixArg : public UIFixedWidget {
 public:
    UIPrefixArg();
    ~UIPrefixArg();

    bool handleEvent(const UIEvent& event, bool second_pass);
    void drawContent(GfxCanvas& can);
};

void startPrefixArg(int n);

#endif
